# Bigraph-viz
A graphviz-based plotting tool for compositional bigraph schema

## Getting Started

Bigraph-viz is available on PyPI [here](https://pypi.org/project/bigraph-viz/0.0.1/), and can be installed as a python 
library like this:

```console
$ pip install bigraph-viz
```

This requires [graphviz](https://pypi.org/project/graphviz/)

<p align="center">
    <img src="https://github.com/vivarium-collective/bigraph-viz/blob/main/doc/_static/nested_composite.png?raw=true" width="340">
</p>
